==> uiadapter-spring-dataaccess-0.4.14-20250818.053238-1-sources.jar: com/nexacro/uiadapter/spring/dao/dbms/Mysql.java <==
package com.nexacro.uiadapter.spring.dao.dbms;

import com.nexacro.uiadapter.spring.dao.AbstractDbms;
import com.nexacro.uiadapter.spring.dao.DbColumn;

/**
 * <p>Mysql에서 사용되는 데이터 타입과 <code>DataSet</code>의 데이터 타입간의 매핑 정보를 제공한다.
 * 		<a href="https://dev.mysql.com/doc/connector-j/8.1/en/connector-j-reference-type-conversions.html">connector-j type conversions</a>
 * @author Park SeongMin
 * @since 08.12.2015
 * @version 1.0
 */
public class Mysql extends AbstractDbms {

    @Override
    public void handleColumnDataType(final DbColumn column) {

        /*
        if ("MEDIUMINT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.INT);
        } else if ("SMALLINT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.INT);
        } else if ("TINYINT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.INT);
        } else if ("INTEGER".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.INT);
        } else if ("INTEGER UNSIGNED".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.LONG);
        } else if ("BIGINT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.LONG);
        } else if ("BIGINT UNSIGNED".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.FLOAT);
        } else if ("REAL".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.FLOAT);
        } else if ("FLOAT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.FLOAT);
        } else if ("DOUBLE".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DOUBLE);
        } else if ("DECIMAL".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.BIG_DECIMAL);
        } else if ("NUMERIC".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.BIG_DECIMAL);
        } else if ("DATETIME".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DATE_TIME);
        } else if ("DATE".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DATE);
        } else if ("YEAR".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DATE);
        } else if ("TIME".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.TIME);
 	    } else if ("LONGVARCHAR".equals(column.getVendorsTypeName())) {
	        column.setDataType(PlatformDataType.STRING);
 	    } else if ("BINARY".equals(column.getVendorsTypeName())) {
	        column.setDataType(PlatformDataType.BLOB);
 	    } else if ("VARBINARY".equals(column.getVendorsTypeName())) {
	        column.setDataType(PlatformDataType.BLOB);
 	    } else if ("LONGVARBINARY".equals(column.getVendorsTypeName())) {
	        column.setDataType(PlatformDataType.BLOB);
 	    } else if ("BIT".equals(column.getVendorsTypeName())) {
	        column.setDataType(PlatformDataType.BOOLEAN);
	    }
        
        if ("MEDIUMINT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.INT);
        } else if ("DATETIME".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DATE_TIME);
        } else if ("YEAR".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DATE);
        }
*/
    }
}

==> uiadapter-spring-dataaccess-1.4.13-20250429.085254-3-sources.jar: com/nexacro/uiadapter/spring/dao/dbms/Mysql.java <==
package com.nexacro.uiadapter.spring.dao.dbms;

import com.nexacro.java.xapi.data.datatype.PlatformDataType;
import com.nexacro.uiadapter.spring.dao.AbstractDbms;
import com.nexacro.uiadapter.spring.dao.DbColumn;

/**
 * <p>Mysql에서 사용되는 데이터 타입과 <code>DataSet</code>의 데이터 타입간의 매핑 정보를 제공한다.
 * 		https://dev.mysql.com/doc/connector-j/8.1/en/connector-j-reference-type-conversions.html
 * @author Park SeongMin
 * @since 08.12.2015
 * @version 1.0
 */
public class Mysql extends AbstractDbms {

    @Override
    public void handleColumnDataType(final DbColumn column) {
        if (column == null) {
            return;
        }
        /*
        if ("MEDIUMINT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.INT);
        } else if ("SMALLINT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.INT);
        } else if ("TINYINT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.INT);
        } else if ("INTEGER".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.INT);
        } else if ("INTEGER UNSIGNED".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.LONG);
        } else if ("BIGINT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.LONG);
        } else if ("BIGINT UNSIGNED".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.FLOAT);
        } else if ("REAL".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.FLOAT);
        } else if ("FLOAT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.FLOAT);
        } else if ("DOUBLE".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DOUBLE);
        } else if ("DECIMAL".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.BIG_DECIMAL);
        } else if ("NUMERIC".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.BIG_DECIMAL);
        } else if ("DATETIME".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DATE_TIME);
        } else if ("DATE".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DATE);
        } else if ("YEAR".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DATE);
        } else if ("TIME".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.TIME);
 	    } else if ("LONGVARCHAR".equals(column.getVendorsTypeName())) {
	        column.setDataType(PlatformDataType.STRING);
 	    } else if ("BINARY".equals(column.getVendorsTypeName())) {
	        column.setDataType(PlatformDataType.BLOB);
 	    } else if ("VARBINARY".equals(column.getVendorsTypeName())) {
	        column.setDataType(PlatformDataType.BLOB);
 	    } else if ("LONGVARBINARY".equals(column.getVendorsTypeName())) {
	        column.setDataType(PlatformDataType.BLOB);
 	    } else if ("BIT".equals(column.getVendorsTypeName())) {
	        column.setDataType(PlatformDataType.BOOLEAN);
	    }
        
        if ("MEDIUMINT".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.INT);
        } else if ("DATETIME".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DATE_TIME);
        } else if ("YEAR".equals(column.getVendorsTypeName())) {
            column.setDataType(PlatformDataType.DATE);
        }
*/
    }
}
